Module traits

Module traits 

Traits

DataController
The data controller implementation.
Observer
The observer trait is used by the cache controller to notify user code about various events that happen in the cache controller.